@@ -259,7 +259,7 @@ setMethodS3("getBuiltinUsername", "GString", function(static, ...) {
 #*/###########################################################################
 setMethodS3("getBuiltinDate", "GString", function(static, format="%Y-%m-%d", ...) {
   args <- list(Sys.time(), format=format);
-  do.call("format", args);
+  do.call(base::format, args);
 }, static=TRUE)
 
 
@@ -291,7 +291,7 @@ setMethodS3("getBuiltinDate", "GString", function(static, format="%Y-%m-%d", ...
 #*/###########################################################################
 setMethodS3("getBuiltinTime", "GString", function(static, format="%H:%M:%S", ...) {
   args <- list(Sys.time(), format=format);
-  do.call("format", args);
+  do.call(base::format, args);
 }, static=TRUE)
 
 
@@ -323,7 +323,7 @@ setMethodS3("getBuiltinTime", "GString", function(static, format="%H:%M:%S", ...
 #*/###########################################################################
 setMethodS3("getBuiltinDatetime", "GString", function(static, format=NULL, ...) {
   args <- list(Sys.time(), format=format);
-  do.call("format", args);
+  do.call(base::format, args);
 }, static=TRUE)
 
 
@@ -502,7 +502,6 @@ setMethodS3("getVariableValue", "GString", function(static, name, attributes="",
     } else if (ww == "envir") {
       if (exists(name, envir=envir, inherits=inherits)) {
         value <- get(name, envir=envir, inherits=inherits);
-        break;
       }
     } else if (ww == "parent") {
       envirL <- NULL;
@@ -626,13 +625,13 @@ setMethodS3("parse", "GString", function(object, ...) {
       } else {
         text <- s;
         text <- gsub("\\\\\\$", "$", text);
-        parts <- append(parts, list(text=text));
+        parts <- c(parts, list(text=text));
         break;
       }
     }
 
     prefix <- list(text=text);
-    parts <- append(parts, prefix);
+    parts <- c(parts, prefix);
 
     last <- pos + matchLen - 1L;
     var <- substr(s, start=pos, stop=last);
@@ -670,7 +669,7 @@ setMethodS3("parse", "GString", function(object, ...) {
     part[[1L]]$attributes <- attributes;
     part[[1L]]$searchReplace <- searchReplace;
 
-    parts <- append(parts, part);
+    parts <- c(parts, part);
 
     s <- substr(s, start=last+1L, stop=nchar(s));
     if (nchar(s) == 0L)
@@ -746,7 +745,7 @@ setMethodS3("evaluate", "GString", function(object, envir=parent.frame(), ...) {
   }
 
   s <- "";
-  for (kk in seq(length=length(parts))) {
+  for (kk in seq_along(parts)) {
     part <- parts[[kk]];
     s <- paste(s, part, sep="");
   }
