@@ -4,7 +4,8 @@
 # @title "Resets recorded warnings"
 #
 # \description{
-#  @get "title". 
+#  @get "title".
+#  \emph{This function only worked with R (< 2.4.0) and is now defunct.}
 # }
 #
 # @synopsis
@@ -17,7 +18,7 @@
 #  Returns (invisibly) the number of warnings removed.
 # }
 #
-# 
+#
 #
 # @author
 #
@@ -26,25 +27,18 @@
 # }
 #
 # @keyword programming
+# @keyword internal
 #*/###########################################################################
 setMethodS3("resetWarnings", "default", function(...) {
-  if (exists("last.warning", envir=.GlobalEnv)) {
-    lw <- get("last.warning", envir=.GlobalEnv);
-    count <- length(lw);
-    rm(list="last.warning", envir=.GlobalEnv);
-  } else {
-    count <- 0;
-  }
-
-  invisible(as.integer(count));
-})
+  .Defunct(msg="R.utils::resetWarnings() only works prior to R v2.4.0. There are no known alternatives.")
+}, deprecated=TRUE)
 
 
 
 ############################################################################
-# HISTORY: 
+# HISTORY:
 # 2007-06-09
-# o Using rm(list="last.warning") instead of rm(last.warning) in 
+# o Using rm(list="last.warning") instead of rm(last.warning) in
 #   resetWarnings().
 # 2005-07-07
 # o Created.
